@@ -12,7 +12,8 @@ use Mouse::Util::TypeConstraints;
 use String::Formatter;
 use namespace::autoclean;
 use Try::Tiny;
-use Term::ANSIColor 2.02 qw(color colorvalid);
+use Term::ANSIColor 2.02 qw(colorvalid);
+my $encolor = \&Term::ANSIColor::color;
 
 use constant CAN_OUTPUT_COLOR => $^O eq 'MSWin32'
     ? try { require Win32::Console::ANSI }
@@ -22,7 +23,7 @@ BEGIN {
     $ENV{ANSI_COLORS_DISABLED} = 1 unless CAN_OUTPUT_COLOR;
 }
 
-our $VERSION = '0.993';
+our $VERSION = '0.994';
 
 has abbrev => (
     is      => 'ro',
@@ -140,14 +141,16 @@ has formatter => (
                 C => sub {
                     if (($_[1] // '') eq ':event') {
                         # Select a color based on some attribute.
-                        return color $_[0]->{event} eq 'deploy' ? 'green'
-                                   : $_[0]->{event} eq 'revert' ? 'blue'
-                                   : 'red';
+                        return $encolor->(
+                            $_[0]->{event} eq 'deploy' ? 'green'
+                                : $_[0]->{event} eq 'revert' ? 'blue'
+                                : 'red'
+                        );
                     }
                     hurl format => __x(
                         '{color} is not a valid ANSI color', color => $_[1]
-                    ) unless $_[1] && colorvalid $_[1];
-                    color $_[1];
+                    ) unless $_[1] && colorvalid( $_[1] );
+                    $encolor->( $_[1] );
                 },
                 s => sub {
                     ( my $s = $_[0]->{note} ) =~ s/\v.*//ms;
